betty.test_utils.plugin.config module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.plugin.config module

Test utilities for `betty.plugin.config`.

class betty.test_utils.plugin.config.PluginConfigurationMappingTestBase

  Bases: `ConfigurationMappingTestBase`[`str`, `_PluginConfigurationT`], `Generic`[`_PluginCoT`, `_PluginConfigurationT`]

  A base class for testing `betty.plugin.config.PluginConfigurationMapping` implementations.

  async get_sut(configurations: Iterable[_PluginConfigurationT] | None = None) → PluginConfigurationMapping[_PluginCoT, _PluginConfigurationT]

    Produce the collection under test.

  async test_new_plugins() → None

    Tests `betty.plugin.config.PluginConfigurationMapping.new_plugins()` implementations.